@@ -42,8 +42,16 @@ simtable.cab <- function(args, nosim = NULL, p = NULL, y.start = NULL){
     y1.new.permute <- temp[[1]]
     conde1.old.permute <- temp[[2]]
     changed <- y1.new.permute[(k + 1) : args$n1]
+
     tf2 <- tf3 <- FALSE
-    tf1 <- all(changed >= 0)
+
+    # HJ
+    N.na <- sum(is.na(changed))
+    if (i==1 & N.na > 0)
+	warning("i = ", i, ": 'changed' has ", N.na, " NAs")
+
+    tf1 <- N.na==0 & all(changed >= 0)
+
     if (tf1){
       y1.new <- y1.new.permute[order(shuffle)]
       y2.new <- round(args$x2invt %*% (args$s - t(args$x1) %*% y1.new))
@@ -76,4 +84,3 @@ simtable.cab <- function(args, nosim = NULL, p = NULL, y.start = NULL){
   }
   return(chain[,order(args$ord)])
 }
-
